@@ -24,6 +24,6 @@ if __name__ == "__main__":
         )
         sys.exit(1)
 
-    from gtredactkit import gtredactkit
+    from gtredactkit import runner
 
-    gtredactkit.main()
+    runner.main()
